@@ -30,6 +30,7 @@
 #include <gtk/gtklabel.h>
 #include <gtk/gtksignal.h>
 
+#include "eel-accessibility.h"
 #include "eel-gtk-macros.h"
 #include "eel-glib-extensions.h"
 
@@ -90,13 +91,14 @@ eel_radio_button_group_class_init (EelRadioButtonGroupClass *radio_button_group_
 	object_class->finalize = eel_radio_button_group_finalize;
 
 	/* Signals */
-	radio_group_signals[CHANGED] = gtk_signal_new ("changed",
-						       G_SIGNAL_RUN_LAST,
-						       GTK_CLASS_TYPE (object_class),
-						       G_STRUCT_OFFSET (EelRadioButtonGroupClass, changed),
-						       gtk_marshal_VOID__VOID,
-						       G_TYPE_NONE, 
-						       0);
+	radio_group_signals[CHANGED] = g_signal_new ("changed",
+						     G_TYPE_FROM_CLASS (object_class),
+						     G_SIGNAL_RUN_LAST,
+						     G_STRUCT_OFFSET (EelRadioButtonGroupClass, changed),
+						     NULL, NULL,
+						     g_cclosure_marshal_VOID__VOID,
+						     G_TYPE_NONE, 
+						     0);
 }
 
 static void
@@ -379,6 +381,22 @@ eel_radio_button_group_set_entry_description_text (EelRadioButtonGroup *button_g
 	}
 }
 
+/* Set an item's accessible description. */
+void
+eel_radio_button_group_set_entry_accessible_description (EelRadioButtonGroup *button_group,
+							 guint entry_index,
+							 const char *description)
+{
+	TableRow	*row;
+
+ 	g_return_if_fail (button_group != NULL);
+	g_return_if_fail (EEL_IS_RADIO_BUTTON_GROUP (button_group));
+	g_return_if_fail (entry_index < g_list_length (button_group->details->rows));
+
+	row = g_list_nth_data (button_group->details->rows, entry_index);
+	eel_accessibility_set_description (row->button, description);
+}
+
 void
 eel_radio_button_group_clear (EelRadioButtonGroup *button_group)
 {
@@ -413,4 +431,3 @@ eel_radio_button_group_clear (EelRadioButtonGroup *button_group)
 	button_group->details->num_items = 0;
 }
 
-
